@@ -30,3 +30,14 @@ def test_example_usage():
 
     assert me.status.favorited == False
     assert me.status.retweeted == False
+
+    user_statuses = api.user_timeline(user_id=1, since_id=0, count=1)
+    assert len(user_statuses) == 1
+
+    status_id = 109813536848077879  # ref. https://mastodon.social/@shuuji3/109813536848077879
+    status = api.get_status(id=status_id)
+    assert status.user.screen_name == 'shuuji3'
+    assert 'Hello from tweepy-mastodon!' in status.text
+
+    status = api.create_favorite(id=status_id)
+    assert status.favourited
