@@ -381,3 +381,193 @@ class API(TweepyAPI):
 
         status = self.mastodon.status(id=id)
         return convert_status(self.mastodon, status, include_user_status=False)
+
+    def create_favorite(self, id, include_entities=None):
+        """create_favorite(id, *, include_entities)
+
+        Favorites the status specified in the ``id`` parameter as the
+        authenticating user.
+
+        Parameters
+        ----------
+        id
+            |sid|
+        include_entities
+            |include_entities|
+
+        Returns
+        -------
+        :class:`~tweepy.models.Status`
+
+        References
+        ----------
+        https://developer.twitter.com/en/docs/twitter-api/v1/tweets/post-and-engage/api-reference/post-favorites-create
+        """
+
+        if include_entities is not None:
+            log.warning('`include_entities` are not implemented in tweepy-mastodon yet')
+
+        try:
+            mastodon_status = self.mastodon.status_favourite(id=id)
+            return convert_status(self.mastodon, mastodon_status, include_user_status=False)
+        except MastodonNotFoundError:
+            raise Exception('404 not found')  # TODO: use actual `tweepy.errors.NotFound`
+
+    def destroy_favorite(self, id, include_entities=None):
+        """destroy_favorite(id, *, include_entities)
+
+        Un-favorites the status specified in the ``id`` parameter as the
+        authenticating user.
+
+        Parameters
+        ----------
+        id
+            |sid|
+        include_entities
+            |include_entities|
+
+        Returns
+        -------
+        :class:`~tweepy.models.Status`
+
+        References
+        ----------
+        https://developer.twitter.com/en/docs/twitter-api/v1/tweets/post-and-engage/api-reference/post-favorites-destroy
+        """
+        if include_entities is not None:
+            log.warning('`include_entities` are not implemented in tweepy-mastodon yet')
+
+        try:
+            mastodon_status = self.mastodon.status_unfavourite(id=id)
+            return convert_status(self.mastodon, mastodon_status, include_user_status=False)
+        except MastodonNotFoundError:
+            raise Exception('404 not found')  # TODO: use actual `tweepy.errors.NotFound`
+
+    def retweet(self, id, trim_user=None):
+        """retweet(id, *, trim_user)
+
+        Retweets a Tweet. Requires the ID of the Tweet you are retweeting.
+
+        Parameters
+        ----------
+        id
+            |sid|
+        trim_user
+            |trim_user|
+
+        Returns
+        -------
+        :class:`~tweepy.models.Status`
+
+        References
+        ----------
+        https://developer.twitter.com/en/docs/twitter-api/v1/tweets/post-and-engage/api-reference/post-statuses-retweet-id
+        """
+
+        if trim_user is not None:
+            log.warning('`trim_user` are not implemented in tweepy-mastodon yet')
+
+        try:
+            mastodon_status = self.mastodon.status_reblog(id=id)
+            return convert_status(self.mastodon, mastodon_status, include_user_status=False)
+        except MastodonNotFoundError:
+            raise Exception('404 not found')  # TODO: use actual `tweepy.errors.NotFound`
+
+    def unretweet(self, id, trim_user=None):
+        """unretweet(id, *, trim_user)
+
+        Untweets a retweeted status. Requires the ID of the retweet to
+        unretweet.
+
+        Parameters
+        ----------
+        id
+            |sid|
+        trim_user
+            |trim_user|
+
+        Returns
+        -------
+        :class:`~tweepy.models.Status`
+
+        References
+        ----------
+        https://developer.twitter.com/en/docs/twitter-api/v1/tweets/post-and-engage/api-reference/post-statuses-unretweet-id
+        """
+        if trim_user is not None:
+            log.warning('`trim_user` are not implemented in tweepy-mastodon yet')
+
+        try:
+            mastodon_status = self.mastodon.status_unreblog(id=id)
+            return convert_status(self.mastodon, mastodon_status, include_user_status=False)
+        except MastodonNotFoundError:
+            raise Exception('404 not found')  # TODO: use actual `tweepy.errors.NotFound`
+
+    def create_friendship(self, screen_name=None, user_id=None, follow=False):
+        """create_friendship(*, screen_name, user_id, follow)
+
+        Create a new friendship with the specified user (aka follow).
+
+        Parameters
+        ----------
+        screen_name
+            |screen_name|
+        user_id
+            |user_id|
+        follow
+            Enable notifications for the target user in addition to becoming
+            friends.
+
+        Returns
+        -------
+        :class:`~tweepy.models.User`
+
+        References
+        ----------
+        https://developer.twitter.com/en/docs/twitter-api/v1/accounts-and-users/follow-search-get-users/api-reference/post-friendships-create
+        """
+        try:
+            user = self.get_user(user_id, screen_name)
+            relationship = self.mastodon.account_follow(id=user.id, notify=follow)
+
+            user['following'] = relationship.following
+            user['notifications'] = relationship.notifying
+            user['follow_request_sent'] = relationship.requested
+
+            return user
+        except MastodonNotFoundError:
+            raise Exception('404 not found')  # TODO: use actual `tweepy.errors.NotFound`
+
+
+    def destroy_friendship(self, screen_name=None, user_id=None):
+        """destroy_friendship(*, screen_name, user_id)
+
+        Destroy a friendship with the specified user (aka unfollow).
+
+        Parameters
+        ----------
+        screen_name
+            |screen_name|
+        user_id
+            |user_id|
+
+        Returns
+        -------
+        :class:`~tweepy.models.User`
+
+        References
+        ----------
+        https://developer.twitter.com/en/docs/twitter-api/v1/accounts-and-users/follow-search-get-users/api-reference/post-friendships-destroy
+        """
+        try:
+            user: User = self.get_user(user_id, screen_name)
+            relationship = self.mastodon.account_unfollow(id=user.id)
+
+            user['following'] = relationship.following
+            user['notifications'] = relationship.notifying
+            user['follow_request_sent'] = relationship.requested
+
+            return user
+        except MastodonNotFoundError:
+            raise Exception('404 not found')  # TODO: use actual `tweepy.errors.NotFound`
+
